@@ -11,8 +11,12 @@ test_that("update_key ...",{
 
     mykey <- as_key(key)
 
-    out <- update_key(mykey, drop = c("f", "h"),
-        x = data.frame(x = c("dog", "cat", "rock"), y = c(1, -1, 1), stringsAsFactors = FALSE))
+    out <- update_key(
+        mykey, 
+        drop = c("f", "h"),
+        x = data.frame(x = c("dog", "cat", "rock"), 
+        y = c(1, -1, 1), stringsAsFactors = FALSE)
+    )
 
     expect_true(is_key(out))
     expect_equal(nrow(out), 27)
